/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.kyuubi

package object session {

  val SET_PREFIX = "set:"
  val ENV_PREFIX = "env:"
  val SYSTEM_PREFIX = "system:"
  val HIVECONF_PREFIX = "hiveconf:"
  val HIVEVAR_PREFIX = "hivevar:"
  val METACONF_PREFIX = "metaconf:"
  val USE_CATALOG = "use:catalog"
  val USE_DATABASE = "use:database"

  val SPARK_PREFIX = "spark."
}
